aboutsummaryrefslogtreecommitdiffstats
path: root/demos/modules/gos/threads_advanced/main.c
diff options
context:
space:
mode:
Diffstat (limited to 'demos/modules/gos/threads_advanced/main.c')
-rw-r--r--demos/modules/gos/threads_advanced/main.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/demos/modules/gos/threads_advanced/main.c b/demos/modules/gos/threads_advanced/main.c
index 89cada9f..8527194e 100644
--- a/demos/modules/gos/threads_advanced/main.c
+++ b/demos/modules/gos/threads_advanced/main.c
@@ -65,11 +65,11 @@ gfxThreadHandle thd;
*/
threadreturn_t Thread_function(void* param)
{
- /* Cast the paramter into a bool pointer so we can use it */
- bool_t* doExit = (bool_t*)param;
+ /* Cast the paramter into a gBool pointer so we can use it */
+ gBool* doExit = (gBool*)param;
/* Execute this until we shall be terminated */
- while (*doExit == FALSE) {
+ while (!*doExit) {
DEBUGWRITE("Message from Thread\n");
gfxSleepMilliseconds(500);
}
@@ -84,12 +84,12 @@ threadreturn_t Thread_function(void* param)
*/
void timerCallback(void* param)
{
- /* Cast the paramter into a bool pointer so we can use it */
- bool_t* threadExit = (bool_t*)param;
+ /* Cast the paramter into a gBool pointer so we can use it */
+ gBool* threadExit = (gBool*)param;
/* Ask the Thread to fall over the end */
DEBUGWRITE("Closing thread!\n");
- *threadExit = TRUE;
+ *threadExit = gTrue;
}
/*
@@ -97,7 +97,7 @@ void timerCallback(void* param)
*/
int main(void)
{
- bool_t exitThread = FALSE;
+ gBool exitThread = gFalse;
gfxInit();
@@ -112,9 +112,9 @@ int main(void)
/* Start the timer. The callback function will be called once after 2000ms
* We will pass the thread handle as a parameter so the timer can ask the thread to terminate
*/
- gtimerStart(&gt, timerCallback, (void*)&exitThread, FALSE, 2000);
+ gtimerStart(&gt, timerCallback, (void*)&exitThread, gFalse, 2000);
- while(TRUE) {
+ while(1) {
DEBUGWRITE("Message from main!\n");
gfxSleepMilliseconds(500);
}